"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
// --- DrawBox ---
const FILL = '│  ';
const ITEM = '├─ ';
const LAST = '└─ ';
const EMPTY = '   ';
function drawBox(depth, empty) {
    const fill = new Array(depth).fill(FILL);
    empty.forEach(index => fill[index] = EMPTY);
    const filled = fill.join('');
    return { item: filled + ITEM, last: filled + LAST };
}
exports.DEF_RENDERER = 'default';
exports.renderer = {
    [exports.DEF_RENDERER](box, item) {
        return box + item.name;
    },
    light(box, item) {
        return chalk_1.default.gray(box) + (item.type === 'dir' ? chalk_1.default.gray(item.name) : item.name);
    },
    dark(box, item) {
        return chalk_1.default.gray(box) + (item.type === 'file' ? chalk_1.default.gray(item.name) : item.name);
    }
};
// --- Pretty ---
function walk(tree, render, depth = 0, empty = []) {
    const result = [];
    const box = drawBox(depth, empty);
    tree.forEach((item, index) => {
        const last = index === tree.length - 1;
        const current = last ? box.last : box.item;
        result.push(render(current, item));
        if (item.type === 'dir' && item.nodes) {
            result.push(...walk(item.nodes, render, depth + 1, last ? [...empty, depth] : empty));
        }
    });
    return result;
}
function pretty(tree, render = exports.renderer[exports.DEF_RENDERER]) {
    return walk(tree, render).join('\n');
}
exports.pretty = pretty;
