/// <reference types="node" />
import { EventEmitter } from 'events';
import * as Model from './model';
export declare const INFINITE_DEPTH = -1;
export declare class TreeView {
    private static addTime(item, stats);
    private static removeHidden(pathfiles);
    private static getMainPaths(paths);
    lastResult: Model.IResult;
    protected providers: Model.IProviders;
    protected opts: Model.IOpts;
    protected events: EventEmitter;
    constructor(opts?: Model.IOptsParam);
    on(event: 'item', listener: Model.OnItemCtx): this;
    on(event: 'ready' | 'tree', listener: Model.OnTree): this;
    on(event: 'add' | 'change' | 'unlink', listener: Model.OnItem): this;
    on(event: 'all', listener: Model.OnAll): this;
    removeListeners(event: Model.Event): this;
    process(path: string, cb?: Model.ProcessCb): Promise<Model.TreeNode[]>;
    watch(path: string, watchFn?: Model.WatchFn): {
        close: () => void;
    };
    refreshResult(paths: string[] | string): Promise<Model.TreeNode[]>;
    protected inject(): void;
    private formatOpts();
    private getPathFactory(rootPath);
    private discover(ctx, tree?);
    private getTreeNode(ctx, name);
    private checkFile(file, search?);
    private checkDirectory(dir, search?, strict?);
    private addError(ctx, item, error);
    private addFile(ctx, item, stats);
    private addContent(ctx, item);
    private addDir(ctx, item);
    private sort(tree);
    /**
     * Note for 'item' event:
     *  - Emitted file never have `content` property.
     *  - Emitted dir always have `nodes` property equal to an empty array.
     */
    private emit(event, item, ctx);
    private emit(event, tree);
    private emit(event, item);
    private filterResult(paths);
    private updateResult(match);
    private extendResult(pathname);
}
