"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const chokidar_1 = require("chokidar");
const path_1 = require("path");
exports.DEF_DEBOUNCE_TIME = 100; // ms
exports.fWatchFn = (rootPath, cb, debounceTime = exports.DEF_DEBOUNCE_TIME) => {
    let fullpaths = [];
    let timeout = null;
    const options = { recursive: true }; // Warning: Only supported on MacOS and Windows!
    const watcher = fs_1.watch(rootPath, options, (event, filename) => {
        const fullpath = path_1.resolve(rootPath, filename);
        if (!fullpaths.includes(fullpath)) {
            fullpaths.push(fullpath);
        }
        if (timeout) {
            clearTimeout(timeout);
        }
        timeout = setTimeout(() => {
            timeout = null;
            cb(fullpaths);
            fullpaths = [];
        }, debounceTime);
    });
    return {
        ready: Promise.resolve(),
        close: () => watcher.close()
    };
};
exports.cWatchFn = (rootPath, cb, debounceTime = exports.DEF_DEBOUNCE_TIME) => {
    let fullpaths = [];
    let timeout = null;
    const options = { ignoreInitial: true };
    const watcher = chokidar_1.watch(rootPath, options);
    watcher.on('all', (event, filename) => {
        if (!['change', 'add', 'addDir', 'unlink', 'unlinkDir'].includes(event)) {
            return;
        }
        const fullpath = path_1.resolve(rootPath, path_1.relative(rootPath, filename));
        if (!fullpaths.includes(fullpath)) {
            fullpaths.push(fullpath);
        }
        if (timeout) {
            clearTimeout(timeout);
        }
        timeout = setTimeout(() => {
            timeout = null;
            cb(fullpaths);
            fullpaths = [];
        }, debounceTime);
    });
    return {
        ready: new Promise(done => watcher.on('ready', () => done())),
        close: () => watcher.close()
    };
};
// `fs.watch` with option `recursive` only supported on MacOS and Windows!
exports.FS_WATCH_SUPPORTED = process.platform === 'darwin' || process.platform === 'win32';
exports.DEF_WATCH_MODULE = exports.FS_WATCH_SUPPORTED ? 'fs' : 'chokidar';
exports.default = exports.FS_WATCH_SUPPORTED ? exports.fWatchFn : exports.cWatchFn;
